@@ -1,5 +1,3 @@
-/* $Id: cpu.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -45,7 +43,7 @@ static const unsigned long _glibtop_sysdeps_cpu_all =
 /* Init function. */
 
 void
-glibtop_init_cpu_s (glibtop *server)
+_glibtop_init_cpu_s (glibtop *server)
 {
     server->sysdeps.cpu = _glibtop_sysdeps_cpu_all;
 }
